@@ -4,6 +4,7 @@ import numpy as np
 import pandas as pd
 import quantipy as qp
 import pickle as cp
+import platform
 
 from PIL import ImageFont
 from .excel_formats import ExcelFormats, _Format
@@ -36,7 +37,8 @@ _SHEET_ATTR = ('str_table',
                'default_url_format',
                'excel2003_style',
                'remove_timezone',
-               'constant_memory')
+               'constant_memory',
+               'max_url_length')
 
 # Defaults for _Sheet.
 _SHEET_DEFAULTS = dict(alternate_bg             = True,
@@ -693,7 +695,13 @@ class _Sheet(Worksheet):
     def truetype(self):
         fn = self.excel._formats.default_attributes['font_name']
         fs = self.excel._formats.default_attributes['font_size']
-        return ImageFont.truetype('%s.ttf' % fn.lower(), fs)
+        try:
+            if platform.system() == "Windows":
+                return ImageFont.truetype('%s.ttf' % fn.lower(), fs)
+            else:
+                return ImageFont.truetype('%s.ttf' % fn, fs)
+        except Exception as e:
+            return  ImageFont.load_default()
 
     def set_row(self, row, height, label=None, font_name=None, font_size=None):
         padding = 5
@@ -1150,7 +1158,7 @@ class _Box(object):
                 name = 'counts'
             else:
                 name = self._row_format_name(**x_contents)
-            
+
             if rel_y == 0:
                 sig_level_row = data != '' and name in ['propstest', 'meanstest']
                 if data == '' or sig_level_row:
@@ -1180,8 +1188,10 @@ class _Box(object):
                 else:
                     if rel_y not in self._columns:
                         if base and not x_contents['is_weighted']:
-                            if data <= self.excel.italicise_level:
-                                self._italic.append(rel_y)
+                            # should rel_y replace data here?
+                            if type(data) != str:
+                                if data <= self.excel.italicise_level:
+                                    self._italic.append(rel_y)
                             self._columns.append(rel_y)
                 if rel_y in self._italic:
                     format_ = cp.loads(cp.dumps(format_, cp.HIGHEST_PROTOCOL))
